# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from pulpcore.client.pulpcore.models.storage_class_enum import StorageClassEnum
from typing import Optional, Set
from typing_extensions import Self

class Domain(BaseModel):
    """
    Serializer for Domain.
    """ # noqa: E501
    name: Annotated[str, Field(min_length=1, strict=True, max_length=50)] = Field(description="A name for this domain.")
    description: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="An optional description.")
    pulp_labels: Optional[Dict[str, Optional[StrictStr]]] = None
    storage_class: StorageClassEnum = Field(description="Backend storage class for domain.  * `pulpcore.app.models.storage.FileSystem` - Use local filesystem as storage * `storages.backends.s3boto3.S3Boto3Storage` - Use Amazon S3 as storage * `storages.backends.azure_storage.AzureStorage` - Use Azure Blob as storage * `pulp_service.app.storage.OCIStorage` - Use OCI as storage")
    storage_settings: Dict[str, Any] = Field(description="Settings for storage class.")
    redirect_to_object_storage: Optional[StrictBool] = Field(default=True, description="Boolean to have the content app redirect to object storage.")
    hide_guarded_distributions: Optional[StrictBool] = Field(default=False, description="Boolean to hide distributions with a content guard in the content app.")
    __properties: ClassVar[List[str]] = ["name", "description", "pulp_labels", "storage_class", "storage_settings", "redirect_to_object_storage", "hide_guarded_distributions"]

    @field_validator('name')
    def name_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[-a-zA-Z0-9_]+$", value):
            raise ValueError(r"must validate the regular expression /^[-a-zA-Z0-9_]+$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Domain from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Domain from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "description": obj.get("description"),
            "pulp_labels": obj.get("pulp_labels"),
            "storage_class": obj.get("storage_class"),
            "storage_settings": obj.get("storage_settings"),
            "redirect_to_object_storage": obj.get("redirect_to_object_storage") if obj.get("redirect_to_object_storage") is not None else True,
            "hide_guarded_distributions": obj.get("hide_guarded_distributions") if obj.get("hide_guarded_distributions") is not None else False
        })
        return _obj





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from datetime import datetime
from pydantic import Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import List, Optional
from typing_extensions import Annotated
from pulpcore.client.pulpcore.models.paginated_repository_version_response_list import PaginatedRepositoryVersionResponseList

from pulpcore.client.pulpcore.api_client import ApiClient, RequestSerialized
from pulpcore.client.pulpcore.api_response import ApiResponse
from pulpcore.client.pulpcore.rest import RESTResponseType


class RepositoryVersionsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def list(
        self,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        content: Annotated[Optional[StrictStr], Field(description="Content Unit referenced by HREF/PRN")] = None,
        content__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Number of results to return per page.")] = None,
        number: Annotated[Optional[StrictInt], Field(description="Filter results where number matches value")] = None,
        number__gt: Annotated[Optional[StrictInt], Field(description="Filter results where number is greater than value")] = None,
        number__gte: Annotated[Optional[StrictInt], Field(description="Filter results where number is greater than or equal to value")] = None,
        number__lt: Annotated[Optional[StrictInt], Field(description="Filter results where number is less than value")] = None,
        number__lte: Annotated[Optional[StrictInt], Field(description="Filter results where number is less than or equal to value")] = None,
        number__range: Annotated[Optional[List[StrictInt]], Field(description="Filter results where number is between two comma separated values")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="The initial index from which to return the results.")] = None,
        ordering: Annotated[Optional[List[StrictStr]], Field(description="Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `number` - Number * `-number` - Number (descending) * `complete` - Complete * `-complete` - Complete (descending) * `info` - Info * `-info` - Info (descending) * `content_ids` - Content ids * `-content_ids` - Content ids (descending) * `pk` - Pk * `-pk` - Pk (descending)")] = None,
        prn__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        pulp_created: Annotated[Optional[datetime], Field(description="Filter results where pulp_created matches value")] = None,
        pulp_created__gt: Annotated[Optional[datetime], Field(description="Filter results where pulp_created is greater than value")] = None,
        pulp_created__gte: Annotated[Optional[datetime], Field(description="Filter results where pulp_created is greater than or equal to value")] = None,
        pulp_created__isnull: Annotated[Optional[StrictBool], Field(description="Filter results where pulp_created has a null value")] = None,
        pulp_created__lt: Annotated[Optional[datetime], Field(description="Filter results where pulp_created is less than value")] = None,
        pulp_created__lte: Annotated[Optional[datetime], Field(description="Filter results where pulp_created is less than or equal to value")] = None,
        pulp_created__range: Annotated[Optional[List[datetime]], Field(description="Filter results where pulp_created is between two comma separated values")] = None,
        pulp_href__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        q: Annotated[Optional[StrictStr], Field(description="Filter results by using NOT, AND and OR operations on other filters")] = None,
        fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to include in the response.")] = None,
        exclude_fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to exclude from the response.")] = None,
        pulp_domain: StrictStr = "default",
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PaginatedRepositoryVersionResponseList:
        """List repository versions

        A mixin to hold the shared get_queryset logic used by RepositoryVersionViewSets.

        :param pulp_domain: (required)
        :type pulp_domain: str
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param content: Content Unit referenced by HREF/PRN
        :type content: str
        :param content__in: Multiple values may be separated by commas.
        :type content__in: List[str]
        :param limit: Number of results to return per page.
        :type limit: int
        :param number: Filter results where number matches value
        :type number: int
        :param number__gt: Filter results where number is greater than value
        :type number__gt: int
        :param number__gte: Filter results where number is greater than or equal to value
        :type number__gte: int
        :param number__lt: Filter results where number is less than value
        :type number__lt: int
        :param number__lte: Filter results where number is less than or equal to value
        :type number__lte: int
        :param number__range: Filter results where number is between two comma separated values
        :type number__range: List[int]
        :param offset: The initial index from which to return the results.
        :type offset: int
        :param ordering: Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `number` - Number * `-number` - Number (descending) * `complete` - Complete * `-complete` - Complete (descending) * `info` - Info * `-info` - Info (descending) * `content_ids` - Content ids * `-content_ids` - Content ids (descending) * `pk` - Pk * `-pk` - Pk (descending)
        :type ordering: List[str]
        :param prn__in: Multiple values may be separated by commas.
        :type prn__in: List[str]
        :param pulp_created: Filter results where pulp_created matches value
        :type pulp_created: datetime
        :param pulp_created__gt: Filter results where pulp_created is greater than value
        :type pulp_created__gt: datetime
        :param pulp_created__gte: Filter results where pulp_created is greater than or equal to value
        :type pulp_created__gte: datetime
        :param pulp_created__isnull: Filter results where pulp_created has a null value
        :type pulp_created__isnull: bool
        :param pulp_created__lt: Filter results where pulp_created is less than value
        :type pulp_created__lt: datetime
        :param pulp_created__lte: Filter results where pulp_created is less than or equal to value
        :type pulp_created__lte: datetime
        :param pulp_created__range: Filter results where pulp_created is between two comma separated values
        :type pulp_created__range: List[datetime]
        :param pulp_href__in: Multiple values may be separated by commas.
        :type pulp_href__in: List[str]
        :param q: Filter results by using NOT, AND and OR operations on other filters
        :type q: str
        :param fields: A list of fields to include in the response.
        :type fields: List[str]
        :param exclude_fields: A list of fields to exclude from the response.
        :type exclude_fields: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_serialize(
            pulp_domain=pulp_domain,
            x_task_diagnostics=x_task_diagnostics,
            content=content,
            content__in=content__in,
            limit=limit,
            number=number,
            number__gt=number__gt,
            number__gte=number__gte,
            number__lt=number__lt,
            number__lte=number__lte,
            number__range=number__range,
            offset=offset,
            ordering=ordering,
            prn__in=prn__in,
            pulp_created=pulp_created,
            pulp_created__gt=pulp_created__gt,
            pulp_created__gte=pulp_created__gte,
            pulp_created__isnull=pulp_created__isnull,
            pulp_created__lt=pulp_created__lt,
            pulp_created__lte=pulp_created__lte,
            pulp_created__range=pulp_created__range,
            pulp_href__in=pulp_href__in,
            q=q,
            fields=fields,
            exclude_fields=exclude_fields,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedRepositoryVersionResponseList",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def list_with_http_info(
        self,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        content: Annotated[Optional[StrictStr], Field(description="Content Unit referenced by HREF/PRN")] = None,
        content__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Number of results to return per page.")] = None,
        number: Annotated[Optional[StrictInt], Field(description="Filter results where number matches value")] = None,
        number__gt: Annotated[Optional[StrictInt], Field(description="Filter results where number is greater than value")] = None,
        number__gte: Annotated[Optional[StrictInt], Field(description="Filter results where number is greater than or equal to value")] = None,
        number__lt: Annotated[Optional[StrictInt], Field(description="Filter results where number is less than value")] = None,
        number__lte: Annotated[Optional[StrictInt], Field(description="Filter results where number is less than or equal to value")] = None,
        number__range: Annotated[Optional[List[StrictInt]], Field(description="Filter results where number is between two comma separated values")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="The initial index from which to return the results.")] = None,
        ordering: Annotated[Optional[List[StrictStr]], Field(description="Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `number` - Number * `-number` - Number (descending) * `complete` - Complete * `-complete` - Complete (descending) * `info` - Info * `-info` - Info (descending) * `content_ids` - Content ids * `-content_ids` - Content ids (descending) * `pk` - Pk * `-pk` - Pk (descending)")] = None,
        prn__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        pulp_created: Annotated[Optional[datetime], Field(description="Filter results where pulp_created matches value")] = None,
        pulp_created__gt: Annotated[Optional[datetime], Field(description="Filter results where pulp_created is greater than value")] = None,
        pulp_created__gte: Annotated[Optional[datetime], Field(description="Filter results where pulp_created is greater than or equal to value")] = None,
        pulp_created__isnull: Annotated[Optional[StrictBool], Field(description="Filter results where pulp_created has a null value")] = None,
        pulp_created__lt: Annotated[Optional[datetime], Field(description="Filter results where pulp_created is less than value")] = None,
        pulp_created__lte: Annotated[Optional[datetime], Field(description="Filter results where pulp_created is less than or equal to value")] = None,
        pulp_created__range: Annotated[Optional[List[datetime]], Field(description="Filter results where pulp_created is between two comma separated values")] = None,
        pulp_href__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        q: Annotated[Optional[StrictStr], Field(description="Filter results by using NOT, AND and OR operations on other filters")] = None,
        fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to include in the response.")] = None,
        exclude_fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to exclude from the response.")] = None,
        pulp_domain: StrictStr = "default",
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PaginatedRepositoryVersionResponseList]:
        """List repository versions

        A mixin to hold the shared get_queryset logic used by RepositoryVersionViewSets.

        :param pulp_domain: (required)
        :type pulp_domain: str
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param content: Content Unit referenced by HREF/PRN
        :type content: str
        :param content__in: Multiple values may be separated by commas.
        :type content__in: List[str]
        :param limit: Number of results to return per page.
        :type limit: int
        :param number: Filter results where number matches value
        :type number: int
        :param number__gt: Filter results where number is greater than value
        :type number__gt: int
        :param number__gte: Filter results where number is greater than or equal to value
        :type number__gte: int
        :param number__lt: Filter results where number is less than value
        :type number__lt: int
        :param number__lte: Filter results where number is less than or equal to value
        :type number__lte: int
        :param number__range: Filter results where number is between two comma separated values
        :type number__range: List[int]
        :param offset: The initial index from which to return the results.
        :type offset: int
        :param ordering: Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `number` - Number * `-number` - Number (descending) * `complete` - Complete * `-complete` - Complete (descending) * `info` - Info * `-info` - Info (descending) * `content_ids` - Content ids * `-content_ids` - Content ids (descending) * `pk` - Pk * `-pk` - Pk (descending)
        :type ordering: List[str]
        :param prn__in: Multiple values may be separated by commas.
        :type prn__in: List[str]
        :param pulp_created: Filter results where pulp_created matches value
        :type pulp_created: datetime
        :param pulp_created__gt: Filter results where pulp_created is greater than value
        :type pulp_created__gt: datetime
        :param pulp_created__gte: Filter results where pulp_created is greater than or equal to value
        :type pulp_created__gte: datetime
        :param pulp_created__isnull: Filter results where pulp_created has a null value
        :type pulp_created__isnull: bool
        :param pulp_created__lt: Filter results where pulp_created is less than value
        :type pulp_created__lt: datetime
        :param pulp_created__lte: Filter results where pulp_created is less than or equal to value
        :type pulp_created__lte: datetime
        :param pulp_created__range: Filter results where pulp_created is between two comma separated values
        :type pulp_created__range: List[datetime]
        :param pulp_href__in: Multiple values may be separated by commas.
        :type pulp_href__in: List[str]
        :param q: Filter results by using NOT, AND and OR operations on other filters
        :type q: str
        :param fields: A list of fields to include in the response.
        :type fields: List[str]
        :param exclude_fields: A list of fields to exclude from the response.
        :type exclude_fields: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_serialize(
            pulp_domain=pulp_domain,
            x_task_diagnostics=x_task_diagnostics,
            content=content,
            content__in=content__in,
            limit=limit,
            number=number,
            number__gt=number__gt,
            number__gte=number__gte,
            number__lt=number__lt,
            number__lte=number__lte,
            number__range=number__range,
            offset=offset,
            ordering=ordering,
            prn__in=prn__in,
            pulp_created=pulp_created,
            pulp_created__gt=pulp_created__gt,
            pulp_created__gte=pulp_created__gte,
            pulp_created__isnull=pulp_created__isnull,
            pulp_created__lt=pulp_created__lt,
            pulp_created__lte=pulp_created__lte,
            pulp_created__range=pulp_created__range,
            pulp_href__in=pulp_href__in,
            q=q,
            fields=fields,
            exclude_fields=exclude_fields,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedRepositoryVersionResponseList",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def list_without_preload_content(
        self,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        content: Annotated[Optional[StrictStr], Field(description="Content Unit referenced by HREF/PRN")] = None,
        content__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Number of results to return per page.")] = None,
        number: Annotated[Optional[StrictInt], Field(description="Filter results where number matches value")] = None,
        number__gt: Annotated[Optional[StrictInt], Field(description="Filter results where number is greater than value")] = None,
        number__gte: Annotated[Optional[StrictInt], Field(description="Filter results where number is greater than or equal to value")] = None,
        number__lt: Annotated[Optional[StrictInt], Field(description="Filter results where number is less than value")] = None,
        number__lte: Annotated[Optional[StrictInt], Field(description="Filter results where number is less than or equal to value")] = None,
        number__range: Annotated[Optional[List[StrictInt]], Field(description="Filter results where number is between two comma separated values")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="The initial index from which to return the results.")] = None,
        ordering: Annotated[Optional[List[StrictStr]], Field(description="Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `number` - Number * `-number` - Number (descending) * `complete` - Complete * `-complete` - Complete (descending) * `info` - Info * `-info` - Info (descending) * `content_ids` - Content ids * `-content_ids` - Content ids (descending) * `pk` - Pk * `-pk` - Pk (descending)")] = None,
        prn__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        pulp_created: Annotated[Optional[datetime], Field(description="Filter results where pulp_created matches value")] = None,
        pulp_created__gt: Annotated[Optional[datetime], Field(description="Filter results where pulp_created is greater than value")] = None,
        pulp_created__gte: Annotated[Optional[datetime], Field(description="Filter results where pulp_created is greater than or equal to value")] = None,
        pulp_created__isnull: Annotated[Optional[StrictBool], Field(description="Filter results where pulp_created has a null value")] = None,
        pulp_created__lt: Annotated[Optional[datetime], Field(description="Filter results where pulp_created is less than value")] = None,
        pulp_created__lte: Annotated[Optional[datetime], Field(description="Filter results where pulp_created is less than or equal to value")] = None,
        pulp_created__range: Annotated[Optional[List[datetime]], Field(description="Filter results where pulp_created is between two comma separated values")] = None,
        pulp_href__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        q: Annotated[Optional[StrictStr], Field(description="Filter results by using NOT, AND and OR operations on other filters")] = None,
        fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to include in the response.")] = None,
        exclude_fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to exclude from the response.")] = None,
        pulp_domain: StrictStr = "default",
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List repository versions

        A mixin to hold the shared get_queryset logic used by RepositoryVersionViewSets.

        :param pulp_domain: (required)
        :type pulp_domain: str
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param content: Content Unit referenced by HREF/PRN
        :type content: str
        :param content__in: Multiple values may be separated by commas.
        :type content__in: List[str]
        :param limit: Number of results to return per page.
        :type limit: int
        :param number: Filter results where number matches value
        :type number: int
        :param number__gt: Filter results where number is greater than value
        :type number__gt: int
        :param number__gte: Filter results where number is greater than or equal to value
        :type number__gte: int
        :param number__lt: Filter results where number is less than value
        :type number__lt: int
        :param number__lte: Filter results where number is less than or equal to value
        :type number__lte: int
        :param number__range: Filter results where number is between two comma separated values
        :type number__range: List[int]
        :param offset: The initial index from which to return the results.
        :type offset: int
        :param ordering: Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `number` - Number * `-number` - Number (descending) * `complete` - Complete * `-complete` - Complete (descending) * `info` - Info * `-info` - Info (descending) * `content_ids` - Content ids * `-content_ids` - Content ids (descending) * `pk` - Pk * `-pk` - Pk (descending)
        :type ordering: List[str]
        :param prn__in: Multiple values may be separated by commas.
        :type prn__in: List[str]
        :param pulp_created: Filter results where pulp_created matches value
        :type pulp_created: datetime
        :param pulp_created__gt: Filter results where pulp_created is greater than value
        :type pulp_created__gt: datetime
        :param pulp_created__gte: Filter results where pulp_created is greater than or equal to value
        :type pulp_created__gte: datetime
        :param pulp_created__isnull: Filter results where pulp_created has a null value
        :type pulp_created__isnull: bool
        :param pulp_created__lt: Filter results where pulp_created is less than value
        :type pulp_created__lt: datetime
        :param pulp_created__lte: Filter results where pulp_created is less than or equal to value
        :type pulp_created__lte: datetime
        :param pulp_created__range: Filter results where pulp_created is between two comma separated values
        :type pulp_created__range: List[datetime]
        :param pulp_href__in: Multiple values may be separated by commas.
        :type pulp_href__in: List[str]
        :param q: Filter results by using NOT, AND and OR operations on other filters
        :type q: str
        :param fields: A list of fields to include in the response.
        :type fields: List[str]
        :param exclude_fields: A list of fields to exclude from the response.
        :type exclude_fields: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_serialize(
            pulp_domain=pulp_domain,
            x_task_diagnostics=x_task_diagnostics,
            content=content,
            content__in=content__in,
            limit=limit,
            number=number,
            number__gt=number__gt,
            number__gte=number__gte,
            number__lt=number__lt,
            number__lte=number__lte,
            number__range=number__range,
            offset=offset,
            ordering=ordering,
            prn__in=prn__in,
            pulp_created=pulp_created,
            pulp_created__gt=pulp_created__gt,
            pulp_created__gte=pulp_created__gte,
            pulp_created__isnull=pulp_created__isnull,
            pulp_created__lt=pulp_created__lt,
            pulp_created__lte=pulp_created__lte,
            pulp_created__range=pulp_created__range,
            pulp_href__in=pulp_href__in,
            q=q,
            fields=fields,
            exclude_fields=exclude_fields,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedRepositoryVersionResponseList",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_serialize(
        self,
        pulp_domain,
        x_task_diagnostics,
        content,
        content__in,
        limit,
        number,
        number__gt,
        number__gte,
        number__lt,
        number__lte,
        number__range,
        offset,
        ordering,
        prn__in,
        pulp_created,
        pulp_created__gt,
        pulp_created__gte,
        pulp_created__isnull,
        pulp_created__lt,
        pulp_created__lte,
        pulp_created__range,
        pulp_href__in,
        q,
        fields,
        exclude_fields,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'X-Task-Diagnostics': 'csv',
            'content__in': 'csv',
            'number__range': 'csv',
            'ordering': 'csv',
            'prn__in': 'csv',
            'pulp_created__range': 'csv',
            'pulp_href__in': 'csv',
            'fields': 'multi',
            'exclude_fields': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if pulp_domain is not None:
            _path_params['pulp_domain'] = pulp_domain
        # process the query parameters
        if content is not None:
            
            _query_params.append(('content', content))
            
        if content__in is not None:
            
            _query_params.append(('content__in', content__in))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if number is not None:
            
            _query_params.append(('number', number))
            
        if number__gt is not None:
            
            _query_params.append(('number__gt', number__gt))
            
        if number__gte is not None:
            
            _query_params.append(('number__gte', number__gte))
            
        if number__lt is not None:
            
            _query_params.append(('number__lt', number__lt))
            
        if number__lte is not None:
            
            _query_params.append(('number__lte', number__lte))
            
        if number__range is not None:
            
            _query_params.append(('number__range', number__range))
            
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        if ordering is not None:
            
            _query_params.append(('ordering', ordering))
            
        if prn__in is not None:
            
            _query_params.append(('prn__in', prn__in))
            
        if pulp_created is not None:
            if isinstance(pulp_created, datetime):
                _query_params.append(
                    (
                        'pulp_created',
                        pulp_created.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('pulp_created', pulp_created))
            
        if pulp_created__gt is not None:
            if isinstance(pulp_created__gt, datetime):
                _query_params.append(
                    (
                        'pulp_created__gt',
                        pulp_created__gt.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('pulp_created__gt', pulp_created__gt))
            
        if pulp_created__gte is not None:
            if isinstance(pulp_created__gte, datetime):
                _query_params.append(
                    (
                        'pulp_created__gte',
                        pulp_created__gte.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('pulp_created__gte', pulp_created__gte))
            
        if pulp_created__isnull is not None:
            
            _query_params.append(('pulp_created__isnull', pulp_created__isnull))
            
        if pulp_created__lt is not None:
            if isinstance(pulp_created__lt, datetime):
                _query_params.append(
                    (
                        'pulp_created__lt',
                        pulp_created__lt.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('pulp_created__lt', pulp_created__lt))
            
        if pulp_created__lte is not None:
            if isinstance(pulp_created__lte, datetime):
                _query_params.append(
                    (
                        'pulp_created__lte',
                        pulp_created__lte.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('pulp_created__lte', pulp_created__lte))
            
        if pulp_created__range is not None:
            
            _query_params.append(('pulp_created__range', pulp_created__range))
            
        if pulp_href__in is not None:
            
            _query_params.append(('pulp_href__in', pulp_href__in))
            
        if q is not None:
            
            _query_params.append(('q', q))
            
        if fields is not None:
            
            _query_params.append(('fields', fields))
            
        if exclude_fields is not None:
            
            _query_params.append(('exclude_fields', exclude_fields))
            
        # process the header parameters
        if x_task_diagnostics is not None:
            _header_params['X-Task-Diagnostics'] = x_task_diagnostics
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'json_header_remote_authentication', 
            'basicAuth', 
            'cookieAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/pulp/{pulp_domain}/api/v3/repository_versions/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulpcore.models.app_status_response import AppStatusResponse

class TestAppStatusResponse(unittest.TestCase):
    """AppStatusResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppStatusResponse:
        """Test AppStatusResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppStatusResponse`
        """
        model = AppStatusResponse()
        if include_optional:
            return AppStatusResponse(
                name = '',
                last_heartbeat = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                versions = {
                    'key' : ''
                    }
            )
        else:
            return AppStatusResponse(
        )
        """

    def testAppStatusResponse(self):
        """Test AppStatusResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from pulpcore.client.pulpcore.models.access_policy import AccessPolicy
from pulpcore.client.pulpcore.models.access_policy_response import AccessPolicyResponse
from pulpcore.client.pulpcore.models.app_status_response import AppStatusResponse
from pulpcore.client.pulpcore.models.artifact_distribution_response import ArtifactDistributionResponse
from pulpcore.client.pulpcore.models.artifact_response import ArtifactResponse
from pulpcore.client.pulpcore.models.async_operation_response import AsyncOperationResponse
from pulpcore.client.pulpcore.models.composite_content_guard import CompositeContentGuard
from pulpcore.client.pulpcore.models.composite_content_guard_response import CompositeContentGuardResponse
from pulpcore.client.pulpcore.models.content_guard_response import ContentGuardResponse
from pulpcore.client.pulpcore.models.content_redirect_content_guard import ContentRedirectContentGuard
from pulpcore.client.pulpcore.models.content_redirect_content_guard_response import ContentRedirectContentGuardResponse
from pulpcore.client.pulpcore.models.content_settings_response import ContentSettingsResponse
from pulpcore.client.pulpcore.models.content_summary_response import ContentSummaryResponse
from pulpcore.client.pulpcore.models.database_connection_response import DatabaseConnectionResponse
from pulpcore.client.pulpcore.models.distribution_response import DistributionResponse
from pulpcore.client.pulpcore.models.domain import Domain
from pulpcore.client.pulpcore.models.domain_backend_migrator import DomainBackendMigrator
from pulpcore.client.pulpcore.models.domain_response import DomainResponse
from pulpcore.client.pulpcore.models.evaluation_response import EvaluationResponse
from pulpcore.client.pulpcore.models.filesystem_export import FilesystemExport
from pulpcore.client.pulpcore.models.filesystem_export_response import FilesystemExportResponse
from pulpcore.client.pulpcore.models.filesystem_exporter import FilesystemExporter
from pulpcore.client.pulpcore.models.filesystem_exporter_response import FilesystemExporterResponse
from pulpcore.client.pulpcore.models.generic_remote_response import GenericRemoteResponse
from pulpcore.client.pulpcore.models.generic_remote_response_hidden_fields_inner import GenericRemoteResponseHiddenFieldsInner
from pulpcore.client.pulpcore.models.generic_remote_response_policy_enum import GenericRemoteResponsePolicyEnum
from pulpcore.client.pulpcore.models.group import Group
from pulpcore.client.pulpcore.models.group_progress_report_response import GroupProgressReportResponse
from pulpcore.client.pulpcore.models.group_response import GroupResponse
from pulpcore.client.pulpcore.models.group_role import GroupRole
from pulpcore.client.pulpcore.models.group_role_response import GroupRoleResponse
from pulpcore.client.pulpcore.models.group_user import GroupUser
from pulpcore.client.pulpcore.models.group_user_response import GroupUserResponse
from pulpcore.client.pulpcore.models.header_content_guard import HeaderContentGuard
from pulpcore.client.pulpcore.models.header_content_guard_response import HeaderContentGuardResponse
from pulpcore.client.pulpcore.models.import_response import ImportResponse
from pulpcore.client.pulpcore.models.login_response import LoginResponse
from pulpcore.client.pulpcore.models.method_enum import MethodEnum
from pulpcore.client.pulpcore.models.minimal_task_response import MinimalTaskResponse
from pulpcore.client.pulpcore.models.multiple_artifact_content_response import MultipleArtifactContentResponse
from pulpcore.client.pulpcore.models.my_permissions_response import MyPermissionsResponse
from pulpcore.client.pulpcore.models.nested_open_pgp_public_subkey import NestedOpenPGPPublicSubkey
from pulpcore.client.pulpcore.models.nested_open_pgp_public_subkey_response import NestedOpenPGPPublicSubkeyResponse
from pulpcore.client.pulpcore.models.nested_open_pgp_signature import NestedOpenPGPSignature
from pulpcore.client.pulpcore.models.nested_open_pgp_signature_response import NestedOpenPGPSignatureResponse
from pulpcore.client.pulpcore.models.nested_open_pgp_user_attribute import NestedOpenPGPUserAttribute
from pulpcore.client.pulpcore.models.nested_open_pgp_user_attribute_response import NestedOpenPGPUserAttributeResponse
from pulpcore.client.pulpcore.models.nested_open_pgp_user_id import NestedOpenPGPUserID
from pulpcore.client.pulpcore.models.nested_open_pgp_user_id_response import NestedOpenPGPUserIDResponse
from pulpcore.client.pulpcore.models.nested_role import NestedRole
from pulpcore.client.pulpcore.models.nested_role_response import NestedRoleResponse
from pulpcore.client.pulpcore.models.object_roles_response import ObjectRolesResponse
from pulpcore.client.pulpcore.models.open_pgp_distribution import OpenPGPDistribution
from pulpcore.client.pulpcore.models.open_pgp_distribution_response import OpenPGPDistributionResponse
from pulpcore.client.pulpcore.models.open_pgp_keyring import OpenPGPKeyring
from pulpcore.client.pulpcore.models.open_pgp_keyring_response import OpenPGPKeyringResponse
from pulpcore.client.pulpcore.models.open_pgp_public_key_response import OpenPGPPublicKeyResponse
from pulpcore.client.pulpcore.models.open_pgp_public_subkey_response import OpenPGPPublicSubkeyResponse
from pulpcore.client.pulpcore.models.open_pgp_signature_response import OpenPGPSignatureResponse
from pulpcore.client.pulpcore.models.open_pgp_user_attribute_response import OpenPGPUserAttributeResponse
from pulpcore.client.pulpcore.models.open_pgp_user_id_response import OpenPGPUserIDResponse
from pulpcore.client.pulpcore.models.orphans_cleanup import OrphansCleanup
from pulpcore.client.pulpcore.models.paginated_access_policy_response_list import PaginatedAccessPolicyResponseList
from pulpcore.client.pulpcore.models.paginated_artifact_distribution_response_list import PaginatedArtifactDistributionResponseList
from pulpcore.client.pulpcore.models.paginated_artifact_response_list import PaginatedArtifactResponseList
from pulpcore.client.pulpcore.models.paginated_composite_content_guard_response_list import PaginatedCompositeContentGuardResponseList
from pulpcore.client.pulpcore.models.paginated_content_guard_response_list import PaginatedContentGuardResponseList
from pulpcore.client.pulpcore.models.paginated_content_redirect_content_guard_response_list import PaginatedContentRedirectContentGuardResponseList
from pulpcore.client.pulpcore.models.paginated_distribution_response_list import PaginatedDistributionResponseList
from pulpcore.client.pulpcore.models.paginated_domain_response_list import PaginatedDomainResponseList
from pulpcore.client.pulpcore.models.paginated_filesystem_export_response_list import PaginatedFilesystemExportResponseList
from pulpcore.client.pulpcore.models.paginated_filesystem_exporter_response_list import PaginatedFilesystemExporterResponseList
from pulpcore.client.pulpcore.models.paginated_generic_remote_response_list import PaginatedGenericRemoteResponseList
from pulpcore.client.pulpcore.models.paginated_group_response_list import PaginatedGroupResponseList
from pulpcore.client.pulpcore.models.paginated_group_role_response_list import PaginatedGroupRoleResponseList
from pulpcore.client.pulpcore.models.paginated_group_user_response_list import PaginatedGroupUserResponseList
from pulpcore.client.pulpcore.models.paginated_header_content_guard_response_list import PaginatedHeaderContentGuardResponseList
from pulpcore.client.pulpcore.models.paginated_import_response_list import PaginatedImportResponseList
from pulpcore.client.pulpcore.models.paginated_multiple_artifact_content_response_list import PaginatedMultipleArtifactContentResponseList
from pulpcore.client.pulpcore.models.paginated_open_pgp_distribution_response_list import PaginatedOpenPGPDistributionResponseList
from pulpcore.client.pulpcore.models.paginated_open_pgp_keyring_response_list import PaginatedOpenPGPKeyringResponseList
from pulpcore.client.pulpcore.models.paginated_open_pgp_public_key_response_list import PaginatedOpenPGPPublicKeyResponseList
from pulpcore.client.pulpcore.models.paginated_open_pgp_public_subkey_response_list import PaginatedOpenPGPPublicSubkeyResponseList
from pulpcore.client.pulpcore.models.paginated_open_pgp_signature_response_list import PaginatedOpenPGPSignatureResponseList
from pulpcore.client.pulpcore.models.paginated_open_pgp_user_attribute_response_list import PaginatedOpenPGPUserAttributeResponseList
from pulpcore.client.pulpcore.models.paginated_open_pgp_user_id_response_list import PaginatedOpenPGPUserIDResponseList
from pulpcore.client.pulpcore.models.paginated_publication_response_list import PaginatedPublicationResponseList
from pulpcore.client.pulpcore.models.paginated_pulp_export_response_list import PaginatedPulpExportResponseList
from pulpcore.client.pulpcore.models.paginated_pulp_exporter_response_list import PaginatedPulpExporterResponseList
from pulpcore.client.pulpcore.models.paginated_pulp_importer_response_list import PaginatedPulpImporterResponseList
from pulpcore.client.pulpcore.models.paginated_rbac_content_guard_response_list import PaginatedRBACContentGuardResponseList
from pulpcore.client.pulpcore.models.paginated_repository_response_list import PaginatedRepositoryResponseList
from pulpcore.client.pulpcore.models.paginated_repository_version_response_list import PaginatedRepositoryVersionResponseList
from pulpcore.client.pulpcore.models.paginated_role_response_list import PaginatedRoleResponseList
from pulpcore.client.pulpcore.models.paginated_signing_service_response_list import PaginatedSigningServiceResponseList
from pulpcore.client.pulpcore.models.paginated_task_group_response_list import PaginatedTaskGroupResponseList
from pulpcore.client.pulpcore.models.paginated_task_response_list import PaginatedTaskResponseList
from pulpcore.client.pulpcore.models.paginated_task_schedule_response_list import PaginatedTaskScheduleResponseList
from pulpcore.client.pulpcore.models.paginated_upload_response_list import PaginatedUploadResponseList
from pulpcore.client.pulpcore.models.paginated_upstream_pulp_response_list import PaginatedUpstreamPulpResponseList
from pulpcore.client.pulpcore.models.paginated_user_response_list import PaginatedUserResponseList
from pulpcore.client.pulpcore.models.paginated_user_role_response_list import PaginatedUserRoleResponseList
from pulpcore.client.pulpcore.models.paginated_vulnerability_report_response_list import PaginatedVulnerabilityReportResponseList
from pulpcore.client.pulpcore.models.paginated_worker_response_list import PaginatedWorkerResponseList
from pulpcore.client.pulpcore.models.patched_access_policy import PatchedAccessPolicy
from pulpcore.client.pulpcore.models.patched_composite_content_guard import PatchedCompositeContentGuard
from pulpcore.client.pulpcore.models.patched_content_redirect_content_guard import PatchedContentRedirectContentGuard
from pulpcore.client.pulpcore.models.patched_domain import PatchedDomain
from pulpcore.client.pulpcore.models.patched_filesystem_exporter import PatchedFilesystemExporter
from pulpcore.client.pulpcore.models.patched_group import PatchedGroup
from pulpcore.client.pulpcore.models.patched_header_content_guard import PatchedHeaderContentGuard
from pulpcore.client.pulpcore.models.patched_open_pgp_distribution import PatchedOpenPGPDistribution
from pulpcore.client.pulpcore.models.patched_open_pgp_keyring import PatchedOpenPGPKeyring
from pulpcore.client.pulpcore.models.patched_pulp_exporter import PatchedPulpExporter
from pulpcore.client.pulpcore.models.patched_pulp_importer import PatchedPulpImporter
from pulpcore.client.pulpcore.models.patched_rbac_content_guard import PatchedRBACContentGuard
from pulpcore.client.pulpcore.models.patched_role import PatchedRole
from pulpcore.client.pulpcore.models.patched_task_cancel import PatchedTaskCancel
from pulpcore.client.pulpcore.models.patched_upstream_pulp import PatchedUpstreamPulp
from pulpcore.client.pulpcore.models.patched_user import PatchedUser
from pulpcore.client.pulpcore.models.policy357_enum import Policy357Enum
from pulpcore.client.pulpcore.models.profile_artifact_response import ProfileArtifactResponse
from pulpcore.client.pulpcore.models.progress_report_response import ProgressReportResponse
from pulpcore.client.pulpcore.models.publication_response import PublicationResponse
from pulpcore.client.pulpcore.models.pulp_export import PulpExport
from pulpcore.client.pulpcore.models.pulp_export_response import PulpExportResponse
from pulpcore.client.pulpcore.models.pulp_exporter import PulpExporter
from pulpcore.client.pulpcore.models.pulp_exporter_response import PulpExporterResponse
from pulpcore.client.pulpcore.models.pulp_import import PulpImport
from pulpcore.client.pulpcore.models.pulp_import_check import PulpImportCheck
from pulpcore.client.pulpcore.models.pulp_import_check_response import PulpImportCheckResponse
from pulpcore.client.pulpcore.models.pulp_importer import PulpImporter
from pulpcore.client.pulpcore.models.pulp_importer_response import PulpImporterResponse
from pulpcore.client.pulpcore.models.purge import Purge
from pulpcore.client.pulpcore.models.rbac_content_guard import RBACContentGuard
from pulpcore.client.pulpcore.models.rbac_content_guard_response import RBACContentGuardResponse
from pulpcore.client.pulpcore.models.reclaim_space import ReclaimSpace
from pulpcore.client.pulpcore.models.redis_connection_response import RedisConnectionResponse
from pulpcore.client.pulpcore.models.repair import Repair
from pulpcore.client.pulpcore.models.repository_add_remove_content import RepositoryAddRemoveContent
from pulpcore.client.pulpcore.models.repository_response import RepositoryResponse
from pulpcore.client.pulpcore.models.repository_version_response import RepositoryVersionResponse
from pulpcore.client.pulpcore.models.role import Role
from pulpcore.client.pulpcore.models.role_response import RoleResponse
from pulpcore.client.pulpcore.models.set_label import SetLabel
from pulpcore.client.pulpcore.models.set_label_response import SetLabelResponse
from pulpcore.client.pulpcore.models.signing_service_response import SigningServiceResponse
from pulpcore.client.pulpcore.models.states_enum import StatesEnum
from pulpcore.client.pulpcore.models.status_response import StatusResponse
from pulpcore.client.pulpcore.models.storage_class_enum import StorageClassEnum
from pulpcore.client.pulpcore.models.storage_response import StorageResponse
from pulpcore.client.pulpcore.models.task_group_operation_response import TaskGroupOperationResponse
from pulpcore.client.pulpcore.models.task_group_response import TaskGroupResponse
from pulpcore.client.pulpcore.models.task_response import TaskResponse
from pulpcore.client.pulpcore.models.task_schedule_response import TaskScheduleResponse
from pulpcore.client.pulpcore.models.unset_label import UnsetLabel
from pulpcore.client.pulpcore.models.unset_label_response import UnsetLabelResponse
from pulpcore.client.pulpcore.models.upload import Upload
from pulpcore.client.pulpcore.models.upload_chunk_response import UploadChunkResponse
from pulpcore.client.pulpcore.models.upload_commit import UploadCommit
from pulpcore.client.pulpcore.models.upload_detail_response import UploadDetailResponse
from pulpcore.client.pulpcore.models.upload_response import UploadResponse
from pulpcore.client.pulpcore.models.upstream_pulp import UpstreamPulp
from pulpcore.client.pulpcore.models.upstream_pulp_response import UpstreamPulpResponse
from pulpcore.client.pulpcore.models.user import User
from pulpcore.client.pulpcore.models.user_group import UserGroup
from pulpcore.client.pulpcore.models.user_group_response import UserGroupResponse
from pulpcore.client.pulpcore.models.user_response import UserResponse
from pulpcore.client.pulpcore.models.user_role import UserRole
from pulpcore.client.pulpcore.models.user_role_response import UserRoleResponse
from pulpcore.client.pulpcore.models.version_response import VersionResponse
from pulpcore.client.pulpcore.models.vulnerability_report_response import VulnerabilityReportResponse
from pulpcore.client.pulpcore.models.worker_response import WorkerResponse



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulpcore.models.pulp_export import PulpExport

class TestPulpExport(unittest.TestCase):
    """PulpExport unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PulpExport:
        """Test PulpExport
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PulpExport`
        """
        model = PulpExport()
        if include_optional:
            return PulpExport(
                task = '',
                full = True,
                dry_run = True,
                versions = [
                    ''
                    ],
                chunk_size = '0',
                start_versions = [
                    ''
                    ]
            )
        else:
            return PulpExport(
        )
        """

    def testPulpExport(self):
        """Test PulpExport"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class NestedOpenPGPSignatureResponse(BaseModel):
    """
    Base serializer for use with [pulpcore.app.models.Model][]  This ensures that all Serializers provide values for the 'pulp_href` field.  The class provides a default for the ``ref_name`` attribute in the ModelSerializers's ``Meta`` class. This ensures that the OpenAPI definitions of plugins are namespaced properly.
    """ # noqa: E501
    issuer: Optional[StrictStr] = None
    created: datetime
    expiration_time: Optional[StrictStr] = None
    signers_user_id: Optional[StrictStr] = None
    key_expiration_time: Optional[StrictStr] = None
    expired: StrictBool
    key_expired: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["issuer", "created", "expiration_time", "signers_user_id", "key_expiration_time", "expired", "key_expired"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of NestedOpenPGPSignatureResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "key_expired",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if issuer (nullable) is None
        # and model_fields_set contains the field
        if self.issuer is None and "issuer" in self.model_fields_set:
            _dict['issuer'] = None

        # set to None if expiration_time (nullable) is None
        # and model_fields_set contains the field
        if self.expiration_time is None and "expiration_time" in self.model_fields_set:
            _dict['expiration_time'] = None

        # set to None if signers_user_id (nullable) is None
        # and model_fields_set contains the field
        if self.signers_user_id is None and "signers_user_id" in self.model_fields_set:
            _dict['signers_user_id'] = None

        # set to None if key_expiration_time (nullable) is None
        # and model_fields_set contains the field
        if self.key_expiration_time is None and "key_expiration_time" in self.model_fields_set:
            _dict['key_expiration_time'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of NestedOpenPGPSignatureResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "issuer": obj.get("issuer"),
            "created": obj.get("created"),
            "expiration_time": obj.get("expiration_time"),
            "signers_user_id": obj.get("signers_user_id"),
            "key_expiration_time": obj.get("key_expiration_time"),
            "expired": obj.get("expired"),
            "key_expired": obj.get("key_expired")
        })
        return _obj





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulpcore.api.repositories_reclaim_space_api import RepositoriesReclaimSpaceApi


class TestRepositoriesReclaimSpaceApi(unittest.TestCase):
    """RepositoriesReclaimSpaceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RepositoriesReclaimSpaceApi()

    def tearDown(self) -> None:
        pass

    def test_reclaim(self) -> None:
        """Test case for reclaim

        """
        pass


if __name__ == '__main__':
    unittest.main()
